@@ -1,5 +1,6 @@
 from ipywidgets import DOMWidget, register
 from traitlets import Bool, List, Unicode
+
 from ._frontend import module_name, module_version
 
 
@@ -21,10 +22,11 @@ class MolGridWidget(DOMWidget):
         List stating wether a molecule should be kept (True) or filtered out
         (False)
     """
-    _model_name = Unicode('MolGridModel').tag(sync=True)
+
+    _model_name = Unicode("MolGridModel").tag(sync=True)
     _model_module = Unicode(module_name).tag(sync=True)
     _model_module_version = Unicode(module_version).tag(sync=True)
-    _view_name = Unicode('MolGridView').tag(sync=True)
+    _view_name = Unicode("MolGridView").tag(sync=True)
     _view_module = Unicode(module_name).tag(sync=True)
     _view_module_version = Unicode(module_version).tag(sync=True)
 
