@@ -2,6 +2,7 @@ import pytest
 
 from mols2grid import callbacks
 
+
 def test_make_popup_callback():
     popup = callbacks.make_popup_callback(
         title="${title}",
@@ -15,10 +16,12 @@ def test_make_popup_callback():
     assert '<div class="modal-dialog" style="max-width: 42%;">' in popup
 
 
-@pytest.mark.parametrize("title, expected", [
-    ("SMILES", "${data['SMILES']}"),
-    (None, None),
-])
+@pytest.mark.parametrize(
+    "title, expected",
+    [
+        ("SMILES", "${data['SMILES']}"),
+        (None, None),
+    ],
+)
 def test_title_field(title, expected):
     assert callbacks._get_title_field(title) == expected
-
